import { MediaType } from '@volcengine/rtc';
import type { CustomDefinition } from './type';
declare class HuoshanRTC {
    private initDomId;
    private initDomWidth;
    private initDomHeight;
    private videoDomId;
    private hasPushDown;
    private enableMicrophone;
    private enableCamera;
    private screenShotInstance;
    private isFirstRotate;
    private remoteResolution;
    private touchConfig;
    private touchInfo;
    private options;
    private engine;
    private groupEngine;
    private groupRtc;
    private inputElement;
    roomMessage: any;
    autoRecoveryTimer: any;
    errorInfo: any;
    isFirstFrame: boolean;
    firstFrameCount: number;
    rotation: number;
    isGroupControl: boolean;
    /**
     * 安卓对应回车值
     * go：前往 2
     * search：搜索 3
     * send：发送 4
     * next：下一个 5
     * done：完成 6
     * previous：上一个 7
     */
    enterkeyhintObj: {
        2: string;
        3: string;
        4: string;
        5: string;
        6: string;
        7: string;
    };
    callbacks: any;
    logTime: any;
    remoteUserId: string;
    private rotateType;
    constructor(viewId: string, params: any, callbacks: any, logTime: any);
    /** 浏览器是否支持 */
    isSupported(): Promise<boolean>;
    setLogTime(key: any): void;
    addReportInfo(info: any): void;
    setMicrophone(val: boolean): void;
    setCamera(val: boolean): void;
    sendEventReport(operation: any): void;
    /** 触发无操作回收回调函数 */
    triggerRecoveryTimeCallback(): void;
    /** 调用 createEngine 创建一个本地 Engine 引擎对象 */
    createEngine(): Promise<void>;
    createGroupEngine(pads: any[], config: any): Promise<void>;
    /** 手动销毁通过 createEngine 所创建的引擎对象 */
    destroyEngine(): void;
    /**
     * 静音
     */
    muted(): void;
    /**
     * 取消静音
     */
    unmuted(): void;
    /** 按顺序发送文本框 */
    sendGroupInputString(pads: any, strs: any): void;
    /**  群控剪切板  */
    sendGroupInputClipper(pads: any, strs: any): void;
    /** 手动开启音视频流播放 */
    startPlay(): void;
    /** 群控房间信息 */
    sendGroupRoomMessage(message: string): Promise<any>;
    getMsgTemplate(touchType: string, content: object): string;
    /** 获取应用信息 */
    getEquipmentInfo(type: 'app' | 'attr'): void;
    /** 应用卸载 */
    appUnInstall(pkgNames: Array<string>): void;
    /** 发送消息 */
    sendUserMessage(userId: string, message: string, notSendInGroups?: boolean): Promise<unknown>;
    /** 群控退出房间 */
    kickItOutRoom(pads: any): void;
    /** 群控加入房间 */
    joinGroupRoom(pads: any): void;
    /** 进入 RTC 房间 */
    start(isGroupControl?: boolean, pads?: any[]): void;
    /** 远端用户离开房间 */
    onUserLeave(): void;
    setViewSize(width: number, height: number, rotateType?: 0 | 1): void;
    updateUiH5(): Promise<void>;
    /** 远端可见用户加入房间 */
    onUserJoined(): void;
    /** 视频首帧渲染 */
    onRemoteVideoFirstFrame(): void;
    /** 离开 RTC 房间 */
    stop(): Promise<void>;
    /** 房间内新增远端摄像头/麦克风采集音视频流的回调 */
    onUserPublishStream(): void;
    /**
     * 发送摇一摇信息
     */
    sendShakeInfo(time: any): void;
    checkInputState(msg: any): void;
    /** 监听 onRoomMessageReceived 事件 */
    onRoomMessageReceived(): void;
    /** 监听 onUserMessageReceived 事件 */
    onUserMessageReceived(): void;
    /**
     * 将字符串发送到云手机的粘贴板中
     * @param inputStr 需要发送的字符串
     */
    sendInputClipper(inputStr: string): Promise<void>;
    /**
     * 当云手机处于输入状态时，将字符串直接发送到云手机，完成输入
     * @param inputStr 需要发送的字符串
     */
    sendInputString(inputStr: string): Promise<void>;
    /** 清晰度切换 */
    setStreamConfig(config: CustomDefinition): void;
    /**
     * 暂停接收来自远端的媒体流
     * 该方法仅暂停远端流的接收，并不影响远端流的采集和发送。
     * @param mediaType 1 只控制音频; 2 只控制视频; 3 同时控制音频和视频
     */
    pauseAllSubscribedStream(mediaType?: number): Promise<void>;
    /**
     * 恢复接收来自远端的媒体流
     * 该方法仅恢复远端流的接收，并不影响远端流的采集和发送。
     * @param mediaType 1 只控制音频; 2 只控制视频; 3 同时控制音频和视频
     */
    resumeAllSubscribedStream(mediaType?: number): Promise<void>;
    setRemoteVideoRotation(rotation: number): Promise<void>;
    /**
     * 订阅房间内指定的通过摄像头/麦克风采集的媒体流。
     */
    subscribeStream(mediaType: MediaType): Promise<void>;
    /** 旋转VIDEO 容器 1 横屏 0 竖屏 */
    rotateContainerVideo(type?: 0 | 1): void;
    /** 旋转截图 */
    setScreenshotRotation(rotation?: number): void;
    /** 生成封面图 */
    takeScreenshot(rotation?: number): void;
    /** 重新设置大小 */
    resizeScreenshot(width: number, height: number): void;
    /** 显示封面图 */
    showScreenShot(): void;
    /** 显示封面图 */
    hideScreenShot(): void;
    /** 清空封面图 */
    clearScreenShot(): void;
    /**
     * 取消订阅房间内指定的通过摄像头/麦克风采集的媒体流。
     */
    unsubscribeStream(mediaType: MediaType): Promise<void>;
    /** 截图-保存到本地 */
    saveScreenShotToLocal(): Promise<ImageData>;
    /** 截图-保存到云机 */
    saveScreenShotToRemote(): void;
    /**
     * 手动横竖屏：0竖屏，1横屏
     * 对标百度API
     */
    setPhoneRotation(type: number): void;
    private initRotateScreen;
    /**
     * 旋转屏幕
     * @param type 横竖屏：0竖屏，1横屏
     */
    rotateScreen(type: number): Promise<void>;
    /** 手动定位 */
    setGPS(longitude: number, latitude: number): void;
    /** 云机/本地键盘切换(false-云机键盘，true-本地键盘) */
    setKeyboardStyle(keyBoardType: string): void;
    /** 查询输入状态 */
    onCheckInputState(): Promise<void>;
    /**
     * 设置无操作回收时间
     * @param second 秒 默认300s,最大7200s
     */
    setAutoRecycleTime(second: number): void;
    /** 获取无操作回收时间 */
    getAutoRecycleTime(): any;
    /** 底部栏操作按键 */
    sendCommand(command: string): void;
    /** 返回按键事件 */
    goAppUpPage(): void;
    /** 主页按键事件 */
    goAppHome(): void;
    /** 菜单按键事件 */
    goAppMenu(): void;
    /** 音量增加按键事件 */
    increaseVolume(): void;
    /** 音量减少按键事件 */
    decreaseVolume(): void;
    /**
     * 是否接收粘贴板内容回调
     * @param flag true:接收 false:不接收
     */
    saveCloudClipboard(flag: boolean): void;
}
export default HuoshanRTC;
