import "webrtc-adapter";
import type { CustomDefinition } from "./type";
declare class ArmcloudEngine {
    version: string;
    rtcInstance: any;
    rtcOptions: any;
    callbacks: any;
    streamType: any;
    private axiosSource;
    logTime: any;
    constructor(params: any);
    /** 生成uuid */
    generateUUID(): string;
    /** 浏览器是否支持webrTC */
    isSupported(): any;
    /** 销毁引擎 */
    destroyEngine(): void;
    /** 是否开启麦克风 */
    setMicrophone(val: boolean): void;
    /** 是否开启摄像头 */
    setCamera(val: boolean): void;
    /** 手动开启音视频流播放 */
    startPlay(): void;
    setViewSize(width: number, height: number, rotateType?: 0 | 1): void;
    /** 加入房间 */
    start(isGroupControl?: boolean, pads?: any[]): void;
    /** 群控加入房间 */
    joinGroupRoom(pads?: any[]): void;
    /** 踢出群控房间 */
    kickItOutRoom(pads?: any[]): void;
    /** 离开房间 */
    stop(): void;
    /**
     * 静音
     */
    muted(): void;
    /**
     * 取消静音
     */
    unmuted(): void;
    /** app卸载 */
    appUnInstall(pkgNames: Array<string>): void;
    /** 获取云机信息 */
    getEquipmentInfo(type: "app" | "attr"): void;
    /**
     * 将字符串发送到云手机的粘贴板中
     * @param inputStr 剪切板内容
     */
    sendInputClipper(inputStr: string): void;
    /**
     * 将字符串 分别发到云机的剪切板中
     * @param inputStr 剪切板内容
     */
    sendGroupInputClipper(pads: any, strs: any): void;
    /**
     * 将字符串 分别发到云机的输入框中
     * @param inputStr 剪切板内容
     */
    sendGroupInputString(pads: any, strs: any): void;
    /**
     * 当云手机处于输入状态时，将字符串直接发送到云手机，完成输入
     * @param inputStr 剪切板内容
     */
    sendInputString(inputStr: string): void;
    /** 清晰度切换 */
    setStreamConfig(config: CustomDefinition): void;
    /**
     * 暂停接收来自远端的媒体流
     * 该方法仅暂停远端流的接收，并不影响远端流的采集和发送。
     * @param mediaType 1 只控制音频; 2 只控制视频; 3 同时控制音频和视频
     */
    pauseAllSubscribedStream(mediaType?: number): any;
    /**
     * 恢复接收来自远端的媒体流
     * 该方法仅恢复远端流的接收，并不影响远端流的采集和发送。
     * @param mediaType 1 只控制音频; 2 只控制视频; 3 同时控制音频和视频
     */
    resumeAllSubscribedStream(mediaType?: number): any;
    /**
     * 订阅房间内指定的通过摄像头/麦克风采集的媒体流。
     */
    subscribeStream(mediaType?: number): any;
    /**
     * 取消订阅房间内指定的通过摄像头/麦克风采集的媒体流。
     * 该方法对自动订阅和手动订阅模式均适用。
     */
    unsubscribeStream(mediaType?: number): any;
    /** 截图-保存到本地 */
    saveScreenShotToLocal(): Promise<unknown>;
    /** 截图-保存到云机 */
    saveScreenShotToRemote(): void;
    /** 重新设置大小 */
    resizeScreenshot(width: number, height: number): void;
    /** 显示封面图 */
    showScreenShot(): void;
    /** 隐藏封面图 */
    hideScreenShot(): void;
    /** 旋转video */
    rotateContainerVideo(type?: 0 | 1): void;
    /** 旋转截图 */
    setScreenshotRotation(rotation?: number): void;
    /** 生成封面图 */
    takeScreenshot(rotation?: number): void;
    /** 清空封面图 */
    clearScreenShot(): void;
    /**
     * 手动横竖屏
     * 对标百度API
     */
    setPhoneRotation(type: number): void;
    /** 手动定位 */
    setGPS(longitude: number, latitude: number): void;
    /** 云机/本地键盘切换(false-云机键盘，true-本地键盘) */
    setKeyboardStyle(keyBoardType: string): void;
    /**
     * 设置无操作回收时间
     * @param second 秒 默认300s,最大7200s
     */
    setAutoRecycleTime(second: number): void;
    /** 获取无操作回收时间 */
    getAutoRecycleTime(): any;
    /** 底部栏操作按键 */
    sendCommand(command: string): void;
    /** 音量增加按键事件 */
    increaseVolume(): void;
    /** 音量减少按键事件 */
    decreaseVolume(): void;
    /**
     * 是否接收粘贴板内容回调
     * @param flag true:接收 false:不接收
     */
    saveCloudClipboard(flag: boolean): void;
    /**
     * 摇一摇
     * @param time
     */
    sendShake(time?: number): void;
}
export default ArmcloudEngine;
