import type { CustomDefinition } from "./type";
declare class WebRTC {
    private initDomId;
    private initDomWidth;
    private initDomHeight;
    private videoDomId;
    private remoteVideoContainerId;
    private remoteVideoId;
    private remoteaudioAndVideoStream;
    private remoteVideoStream;
    private pingTimer;
    private hasPushDown;
    private refreshUiMsgNumber;
    private getFirstFrame;
    private enableMicrophone;
    private enableCamera;
    private errorInfo;
    private remoteResolution;
    private roomMessage;
    private options;
    private socket;
    private retryCount;
    private retryCountBackup;
    private retryTime;
    private remotePc;
    private dataChannel;
    private remoteUserId;
    private inputElement;
    private autoRecoveryTimer;
    private runInfoTimer;
    private touchConfig;
    private touchInfo;
    /**
     * 安卓对应回车值
     * go：前往 2
     * search：搜索 3
     * send：发送 4
     * next：下一个 5
     * done：完成 6
     * previous：上一个 7
     */
    enterkeyhintObj: {
        2: string;
        3: string;
        4: string;
        5: string;
        6: string;
        7: string;
    };
    private socketParams;
    private callbacks;
    private audioAndVideoStream;
    private audioAndVideoSender;
    private logTime;
    private isGroupControl;
    private groupRtc;
    private groupPads;
    private masterIdPrefix;
    private stopOperation;
    private videoElement;
    constructor(viewId: string, params: any, callbacks: any, logTime: any);
    private setLogTime;
    private sendEventReport;
    private addReportInfo;
    /**
     * AES 解密方法
     * @param {*} encryptData 加密数据
     * @param {*} key 秘钥
     * @returns 解密后数据
     */
    private decryptAES;
    pauseAudioAndVideoMedia(): void;
    private getMsgTemplate;
    /** 获取应用信息 */
    getEquipmentInfo(type: "app" | "attr"): void;
    /** 应用卸载 */
    appUnInstall(pkgNames: Array<string>): void;
    private captureAudioAndVideo;
    private startHeartbeat;
    /** 初始化ws */
    private initWebSocket;
    /**
     * 静音
     */
    muted(): void;
    /**
     * 取消静音
     */
    unmuted(): void;
    startPlay(): void;
    private sendGroupMag;
    /** 群控退出房间 */
    kickItOutRoom(pads: any): void;
    /** 群控加入房间 */
    joinGroupRoom(pads: any): void;
    private createWebGroupRtc;
    /** 滚轮事件 */
    private handleVideoWheel;
    /** 鼠标移出 */
    private handleVideoMouseleave;
    /** 鼠标按下 */
    private handleVideoMousedown;
    /** 鼠标移动 */
    private handleVideoMousemove;
    /** 鼠标结束 */
    private handleVideoMouseup;
    /** 加入房间 */
    start(isGroupControl?: boolean, pads?: any[]): void;
    /** 发送offer */
    private sendOffer;
    /** 接收webrtc offer */
    private receiveOffer;
    /** 接收webrtc answer */
    private receiveAnswer;
    /** 发送webrtc answer */
    private sendAnswer;
    private isFirstFrameSuccess;
    /**
     * 控制轨道声音
     * @param streams
     * @param status
     */
    controlTrackVoice(streams: any, type?: string, status?: boolean): void;
    /** 第一帧加载完成 */
    private renderedFirstFrame;
    /** 等待视频首帧画面被渲染 */
    private waitForFirstFrameRendered;
    /** 停止所有操作 */
    private stopOperations;
    /** 关闭所有资源 但不销毁元素 */
    private close;
    /** 销毁 */
    private destroy;
    stop(describe: any): void;
    /** 定期获取统计信息的函数 */
    private getStats;
    /** 浏览器是否支持 */
    isSupported(): boolean;
    /** 触发无操作回收回调函数 */
    private triggerRecoveryTimeCallback;
    /** 发送消息 */
    sendUserMessage(message: string, notRecycling?: boolean): Promise<void>;
    setMicrophone(val: boolean): void;
    setCamera(val: boolean): void;
    /** 监听广播消息 */
    private onRoomMessageReceived;
    /**
     * 将字符串发送到云手机的粘贴板中
     * @param inputStr 需要发送的字符串
     */
    sendInputClipper(inputStr: string): Promise<void>;
    /** 群控剪切板 */
    sendGroupInputClipper(pads: any, strs: any): void;
    /**
     * 当云手机处于输入状态时，将字符串直接发送到云手机，完成输入
     * @param inputStr 需要发送的字符串
     */
    sendInputString(inputStr: string): Promise<void>;
    /**
     * 发送摇一摇信息
     */
    sendShakeInfo(time: any): void;
    /** 清晰度切换 */
    setStreamConfig(config: CustomDefinition): void;
    private handleSendData;
    /**
     * 暂停接收来自远端的媒体流
     * 该方法仅暂停远端流的接收，并不影响远端流的采集和发送。
     * @param mediaType 1 只控制音频; 2 只控制视频; 3 同时控制音频和视频
     */
    pauseAllSubscribedStream(mediaType?: number): void;
    /**
     * 恢复接收来自远端的媒体流
     * 该方法仅恢复远端流的接收，并不影响远端流的采集和发送。
     * @param mediaType 1 只控制音频; 2 只控制视频; 3 同时控制音频和视频
     */
    resumeAllSubscribedStream(mediaType?: number): void;
    /** 截图-保存到本地 */
    saveScreenShotToLocal(): Promise<unknown>;
    /** 截图-保存到云机 */
    saveScreenShotToRemote(): void;
    /**
     * 手动横竖屏：0竖屏，1横屏
     * 对标百度API
     */
    setPhoneRotation(type: number): void;
    /**
     * 旋转屏幕
     * @param type 横竖屏：0竖屏，1横屏
     */
    rotateScreen(type: number): void;
    /** 手动定位 */
    setGPS(longitude: number, latitude: number): void;
    /** 云机/本地键盘切换(false-云机键盘，true-本地键盘) */
    setKeyboardStyle(keyBoardType: string): void;
    /** 查询输入状态 */
    onCheckInputState(): Promise<void>;
    /**
     * 设置无操作回收时间
     * @param second 秒 默认300s,最大7200s
     */
    setAutoRecycleTime(second: number): void;
    /** 获取无操作回收时间 */
    getAutoRecycleTime(): any;
    /** 底部栏操作按键 */
    sendCommand(command: string): void;
    /** 返回按键事件 */
    private goAppUpPage;
    /** 主页按键事件 */
    private goAppHome;
    /** 菜单按键事件 */
    private goAppMenu;
    /** 音量增加按键事件 */
    increaseVolume(): void;
    /** 音量减少按键事件 */
    decreaseVolume(): void;
    /**
     * 是否接收粘贴板内容回调
     * @param flag true:接收 false:不接收
     */
    saveCloudClipboard(flag: boolean): void;
}
export default WebRTC;
